==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a == null) {
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
            }
            if (a.j(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b(a);
            a.z("GeographicXYTriangulatingSeriesBase", GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, 'GeographicXYTriangulatingSeriesBaseDescriptionMetadata');
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a == null) {
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicXYTriangulatingSeriesBaseDescriptionMetadata.c(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapSeriesHostDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicXYTriangulatingSeriesBaseDescriptionMetadata.b(a);
            a.ab("GeographicXYTriangulatingSeriesBase", GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicXYTriangulatingSeriesBaseDescriptionMetadata, 'GeographicXYTriangulatingSeriesBaseDescriptionMetadata');
    GeographicXYTriangulatingSeriesBaseDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesBaseDescriptionMetadata;
})();
